@@ -27,3 +27,11 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 mod utils;
 pub mod desktop_entry;
 pub mod basedir;
+pub mod icon_theme;
+
+/*
+Future modules:
+
+pub mod desktop_menu;
+
+*/
